@@ -63,11 +63,11 @@ sub combine {
 	for ( @col ) {
 		 my $h    = $s->{rfm}{$_};
 		 my $val  = $d->{$_};
-		 exists $s->{ "udc_$_"} and $val = $s->{ "udc_$_"};
+		 exists $s->{ "udc_$_"} and $d->{$_} = $s->{ "udc_$_"};
 		 next unless $h->{ref};
 		 $d->{$_} =  $h->{ref}( $val );
 	} 
-	join $csv->{sep_char},  map { $_ // '' } @{$d}{@col};
+	join $csv->{sep_char}//'',  map { $_ // '' } @{$d}{@col};
 }
 
 sub  field_nums_reqe {
